summaryrefslogtreecommitdiff
path: root/src/utils/stringutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/utils/stringutils.h')
-rw-r--r--src/utils/stringutils.h25
1 files changed, 15 insertions, 10 deletions
diff --git a/src/utils/stringutils.h b/src/utils/stringutils.h
index da75a42fa..cc479d80c 100644
--- a/src/utils/stringutils.h
+++ b/src/utils/stringutils.h
@@ -64,20 +64,25 @@ std::string &toUpper(std::string &str);
*/
unsigned int atox(const std::string &str) A_WARN_UNUSED;
-template<typename T> std::string toString(const T &arg) A_WARN_UNUSED;
-
/**
- * Converts the given value to a string using std::stringstream.
+ * Converts the given value to a string.
*
* @param arg the value to convert to a string
* @return the string representation of arg
*/
-template<typename T> std::string toString(const T &arg)
-{
- std::stringstream ss;
- ss << arg;
- return ss.str();
-}
+std::string toString(unsigned int num);
+
+std::string toString(size_t num);
+
+std::string toString(unsigned char num);
+
+std::string toString(int num);
+
+std::string toString(uint16_t num);
+
+std::string toString(float num);
+
+std::string toString(double num);
std::string toStringPrint(const unsigned int val);
@@ -64,20 +64,25 @@ std::string &toUpper(std::string &str);
*
- * @param arg the value to convert to a string
+ * @param num the value to convert to a string
* @return the string representation of arg
*/